==> chaosmesh-model-6.9.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/AWSChaosSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class AWSChaosSpecFluent<A extends AWSChaosSpecFluent<A>> extends BaseFluent<A>{
  public AWSChaosSpecFluent() {
  }
  
  public AWSChaosSpecFluent(AWSChaosSpec instance) {
    this.copyInstance(instance);
  }
  private String action;
  private String awsRegion;
  private String deviceName;
  private String duration;
  private String ec2Instance;
  private String endpoint;
  private String secretName;
  private String volumeID;
  
  protected void copyInstance(AWSChaosSpec instance) {
    instance = (instance != null ? instance : new AWSChaosSpec());
    if (instance != null) {
          this.withAction(instance.getAction());
          this.withAwsRegion(instance.getAwsRegion());
          this.withDeviceName(instance.getDeviceName());
          this.withDuration(instance.getDuration());
          this.withEc2Instance(instance.getEc2Instance());
          this.withEndpoint(instance.getEndpoint());
          this.withSecretName(instance.getSecretName());
          this.withVolumeID(instance.getVolumeID());
          this.withAction(instance.getAction());
          this.withAwsRegion(instance.getAwsRegion());
          this.withDeviceName(instance.getDeviceName());
          this.withDuration(instance.getDuration());
          this.withEc2Instance(instance.getEc2Instance());
          this.withEndpoint(instance.getEndpoint());
          this.withSecretName(instance.getSecretName());
          this.withVolumeID(instance.getVolumeID());
        }
  }
  
  public String getAction() {
    return this.action;
  }
  
  public A withAction(String action) {
    this.action = action;
    return (A) this;
  }
  
  public boolean hasAction() {
    return this.action != null;
  }
  
  public String getAwsRegion() {
    return this.awsRegion;
  }
  
  public A withAwsRegion(String awsRegion) {
    this.awsRegion = awsRegion;
    return (A) this;
  }
  
  public boolean hasAwsRegion() {
    return this.awsRegion != null;
  }
  
  public String getDeviceName() {
    return this.deviceName;
  }
  
  public A withDeviceName(String deviceName) {
    this.deviceName = deviceName;
    return (A) this;
  }
  
  public boolean hasDeviceName() {
    return this.deviceName != null;
  }
  
  public String getDuration() {
    return this.duration;
  }
  
  public A withDuration(String duration) {
    this.duration = duration;
    return (A) this;
  }
  
  public boolean hasDuration() {
    return this.duration != null;
  }
  
  public String getEc2Instance() {
    return this.ec2Instance;
  }
  
  public A withEc2Instance(String ec2Instance) {
    this.ec2Instance = ec2Instance;
    return (A) this;
  }
  
  public boolean hasEc2Instance() {
    return this.ec2Instance != null;
  }
  
  public String getEndpoint() {
    return this.endpoint;
  }
  
  public A withEndpoint(String endpoint) {
    this.endpoint = endpoint;
    return (A) this;
  }
  
  public boolean hasEndpoint() {
    return this.endpoint != null;
  }
  
  public String getSecretName() {
    return this.secretName;
  }
  
  public A withSecretName(String secretName) {
    this.secretName = secretName;
    return (A) this;
  }
  
  public boolean hasSecretName() {
    return this.secretName != null;
  }
  
  public String getVolumeID() {
    return this.volumeID;
  }
  
  public A withVolumeID(String volumeID) {
    this.volumeID = volumeID;
    return (A) this;
  }
  
  public boolean hasVolumeID() {
    return this.volumeID != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AWSChaosSpecFluent that = (AWSChaosSpecFluent) o;
    if (!java.util.Objects.equals(action, that.action)) return false;
    if (!java.util.Objects.equals(awsRegion, that.awsRegion)) return false;
    if (!java.util.Objects.equals(deviceName, that.deviceName)) return false;
    if (!java.util.Objects.equals(duration, that.duration)) return false;
    if (!java.util.Objects.equals(ec2Instance, that.ec2Instance)) return false;
    if (!java.util.Objects.equals(endpoint, that.endpoint)) return false;
    if (!java.util.Objects.equals(secretName, that.secretName)) return false;
    if (!java.util.Objects.equals(volumeID, that.volumeID)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(action,  awsRegion,  deviceName,  duration,  ec2Instance,  endpoint,  secretName,  volumeID,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (action != null) { sb.append("action:"); sb.append(action + ","); }
    if (awsRegion != null) { sb.append("awsRegion:"); sb.append(awsRegion + ","); }
    if (deviceName != null) { sb.append("deviceName:"); sb.append(deviceName + ","); }
    if (duration != null) { sb.append("duration:"); sb.append(duration + ","); }
    if (ec2Instance != null) { sb.append("ec2Instance:"); sb.append(ec2Instance + ","); }
    if (endpoint != null) { sb.append("endpoint:"); sb.append(endpoint + ","); }
    if (secretName != null) { sb.append("secretName:"); sb.append(secretName + ","); }
    if (volumeID != null) { sb.append("volumeID:"); sb.append(volumeID); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> chaosmesh-model-7.4.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/AWSChaosSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class AWSChaosSpecFluent<A extends AWSChaosSpecFluent<A>> extends BaseFluent<A>{
  public AWSChaosSpecFluent() {
  }
  
  public AWSChaosSpecFluent(AWSChaosSpec instance) {
    this.copyInstance(instance);
  }
  private String action;
  private String awsRegion;
  private String deviceName;
  private String duration;
  private String ec2Instance;
  private String endpoint;
  private String remoteCluster;
  private String secretName;
  private String volumeID;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(AWSChaosSpec instance) {
    instance = (instance != null ? instance : new AWSChaosSpec());
    if (instance != null) {
          this.withAction(instance.getAction());
          this.withAwsRegion(instance.getAwsRegion());
          this.withDeviceName(instance.getDeviceName());
          this.withDuration(instance.getDuration());
          this.withEc2Instance(instance.getEc2Instance());
          this.withEndpoint(instance.getEndpoint());
          this.withRemoteCluster(instance.getRemoteCluster());
          this.withSecretName(instance.getSecretName());
          this.withVolumeID(instance.getVolumeID());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getAction() {
    return this.action;
  }
  
  public A withAction(String action) {
    this.action = action;
    return (A) this;
  }
  
  public boolean hasAction() {
    return this.action != null;
  }
  
  public String getAwsRegion() {
    return this.awsRegion;
  }
  
  public A withAwsRegion(String awsRegion) {
    this.awsRegion = awsRegion;
    return (A) this;
  }
  
  public boolean hasAwsRegion() {
    return this.awsRegion != null;
  }
  
  public String getDeviceName() {
    return this.deviceName;
  }
  
  public A withDeviceName(String deviceName) {
    this.deviceName = deviceName;
    return (A) this;
  }
  
  public boolean hasDeviceName() {
    return this.deviceName != null;
  }
  
  public String getDuration() {
    return this.duration;
  }
  
  public A withDuration(String duration) {
    this.duration = duration;
    return (A) this;
  }
  
  public boolean hasDuration() {
    return this.duration != null;
  }
  
  public String getEc2Instance() {
    return this.ec2Instance;
  }
  
  public A withEc2Instance(String ec2Instance) {
    this.ec2Instance = ec2Instance;
    return (A) this;
  }
  
  public boolean hasEc2Instance() {
    return this.ec2Instance != null;
  }
  
  public String getEndpoint() {
    return this.endpoint;
  }
  
  public A withEndpoint(String endpoint) {
    this.endpoint = endpoint;
    return (A) this;
  }
  
  public boolean hasEndpoint() {
    return this.endpoint != null;
  }
  
  public String getRemoteCluster() {
    return this.remoteCluster;
  }
  
  public A withRemoteCluster(String remoteCluster) {
    this.remoteCluster = remoteCluster;
    return (A) this;
  }
  
  public boolean hasRemoteCluster() {
    return this.remoteCluster != null;
  }
  
  public String getSecretName() {
    return this.secretName;
  }
  
  public A withSecretName(String secretName) {
    this.secretName = secretName;
    return (A) this;
  }
  
  public boolean hasSecretName() {
    return this.secretName != null;
  }
  
  public String getVolumeID() {
    return this.volumeID;
  }
  
  public A withVolumeID(String volumeID) {
    this.volumeID = volumeID;
    return (A) this;
  }
  
  public boolean hasVolumeID() {
    return this.volumeID != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AWSChaosSpecFluent that = (AWSChaosSpecFluent) o;
    if (!java.util.Objects.equals(action, that.action)) return false;
    if (!java.util.Objects.equals(awsRegion, that.awsRegion)) return false;
    if (!java.util.Objects.equals(deviceName, that.deviceName)) return false;
    if (!java.util.Objects.equals(duration, that.duration)) return false;
    if (!java.util.Objects.equals(ec2Instance, that.ec2Instance)) return false;
    if (!java.util.Objects.equals(endpoint, that.endpoint)) return false;
    if (!java.util.Objects.equals(remoteCluster, that.remoteCluster)) return false;
    if (!java.util.Objects.equals(secretName, that.secretName)) return false;
    if (!java.util.Objects.equals(volumeID, that.volumeID)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(action,  awsRegion,  deviceName,  duration,  ec2Instance,  endpoint,  remoteCluster,  secretName,  volumeID,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (action != null) { sb.append("action:"); sb.append(action + ","); }
    if (awsRegion != null) { sb.append("awsRegion:"); sb.append(awsRegion + ","); }
    if (deviceName != null) { sb.append("deviceName:"); sb.append(deviceName + ","); }
    if (duration != null) { sb.append("duration:"); sb.append(duration + ","); }
    if (ec2Instance != null) { sb.append("ec2Instance:"); sb.append(ec2Instance + ","); }
    if (endpoint != null) { sb.append("endpoint:"); sb.append(endpoint + ","); }
    if (remoteCluster != null) { sb.append("remoteCluster:"); sb.append(remoteCluster + ","); }
    if (secretName != null) { sb.append("secretName:"); sb.append(secretName + ","); }
    if (volumeID != null) { sb.append("volumeID:"); sb.append(volumeID + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
